@@ -17,7 +17,7 @@
  autora (https://github.com/MrYsLab/pymata-aio/tree/master/FirmataPlus)
 '''
 
-_pytechbrain_version_ = '0.7.9'
+_pytechbrain_version_ = '0.7.11'
 
 # definicje nut dla funkcji nuta
 C0=16
@@ -191,9 +191,12 @@ class PyTechBrain:
                 if platform in ("linux", "darwin") and val.product == 'ABIX_PyTechBrain':
                     print(f"Found on {val.device}")
                     return val.device
-                elif platform == "win" and (val.manufacturer == 'FTDI' or val.description.startswith("USB Serial")):
-                    print(f"Found on {val.name}")
-                    return val.name
+                elif platform.startswith("win"):
+                    if val.manufacturer.startswith('FTDI') or val.description.startswith("USB Serial"):
+                        print(f"Found on {val.name}")
+                        return val.name
+                    else:
+                        print(f"Some error in founding: \n {val.description} / {val.manufacturer} / {val.usb_info()} ")
             else:
                 print("Found no adapter....")
                 return False
